#
# Conditional build:
%bcond_with	initrd		# don't build initrd version
%bcond_with	dietlibc	# link initrd version with static glibc instead of dietlibc
%bcond_without	tests		# don't perform "make test"

Summary:	Tool for creating and maintaining software RAID devices
Summary(pl.UTF-8):	Narzędzie do tworzenia i obsługi programowych macierzy RAID
Name:		mdadm
Version:	4.1
Release:	1
License:	GPL v2+
Group:		Base
Source0:	https://www.kernel.org/pub/linux/utils/raid/mdadm/%{name}-%{version}.tar.xz
# Source0-md5:	51bf3651bd73a06c413a2f964f299598
Source1:	%{name}.init
Source2:	%{name}.sysconfig
Source3:	%{name}.cron
Source4:	%{name}-checkarray
Source5:	cronjob-%{name}.timer
Source6:	cronjob-%{name}.service
URL:		https://www.kernel.org/pub/linux/utils/raid/mdadm/
BuildRequires:	dlm-devel
BuildRequires:	groff
BuildRequires:	rpmbuild(macros) >= 1.671
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
%if %{with initrd}
	%if %{with dietlibc}
BuildRequires:	dietlibc-static
	%else
BuildRequires:	glibc-static
	%endif
%endif
Requires(post,preun):	/sbin/chkconfig
Requires:	/sbin/chkconfig
Requires:	rc-scripts >= 0.4.2.4-2
Requires:	systemd-units >= 38
Suggests:	cronjobs
%{!?with_initrd:Obsoletes:	mdadm-initrd < %{version}-%{release}}
Obsoletes:	mdctl
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_sbindir		/sbin

%description
This package includes tool you need to set up and maintain a software
RAID device under Linux. It's thought as an alternative to raidtools
package.

%description -l pl.UTF-8
Pakiet ten zawiera narzędzie potrzebne do tworzenia i obsługi
programowych macierzy RAID. Program ten jest pomyślany jako
alternatywa dla pakietu raidtools.

%package initrd
Summary:	Tool for maintaining software RAID devices - initrd version
Summary(pl.UTF-8):	Narzędzie do obsługi programowych macierzy RAID, wersja dla initrd
Group:		Base
Conflicts:	geninitrd < 12787

%description initrd
Tool for maintaining software RAID devices - statically linked for
initrd.

%description initrd -l pl.UTF-8
Narzędzie do zarządzania programowymi macierzami RAID - statycznie
skonsolidowane na potrzeby initrd.

%prep
%setup -q

%build
%if %{with initrd}
%if %{with dietlibc}
%{__make} mdadm \
	CC="diet %{__cc} %{rpmcflags} %{rpmcppflags} %{rpmldflags} -Os -static" \
	CWFLAGS="-Wall"
%{__mv} mdadm initrd-mdadm
%else
%{__make} mdadm.static \
	CC="%{__cc}" \
	CFLAGS="%{rpmcflags} %{rpmcppflags}" \
	LDFLAGS="%{rpmldflags}"
%{__mv} mdadm.static initrd-mdadm
%endif
%{__make} clean
%endif

%{__make} all mdadm mdadm.8 \
	CC="%{__cc}" \
	CFLAGS="%{rpmcflags} %{rpmcppflags}" \
	LDFLAGS="%{rpmldflags}" \
	SYSCONFDIR="%{_sysconfdir}"

%{?with_tests:%{__make} test}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_sbindir},%{_mandir}/man{5,8}} \
	$RPM_BUILD_ROOT{/etc/{rc.d/init.d,sysconfig,cron.d},%{systemdunitdir}}

%{__make} install install-udev install-systemd \
	DESTDIR=$RPM_BUILD_ROOT

%if %{with initrd}
install -d $RPM_BUILD_ROOT%{_libdir}/initrd
install -p initrd-mdadm $RPM_BUILD_ROOT%{_libdir}/initrd/mdadm
ln -s mdadm $RPM_BUILD_ROOT%{_libdir}/initrd/mdctl
%endif

cp -p mdadm.conf-example $RPM_BUILD_ROOT%{_sysconfdir}/mdadm.conf

ln -s mdadm $RPM_BUILD_ROOT%{_sbindir}/mdctl

install -p %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/%{name}
cp -p %{SOURCE2} $RPM_BUILD_ROOT/etc/sysconfig/%{name}

cp -p %{SOURCE3} $RPM_BUILD_ROOT/etc/cron.d/mdadm-checkarray
install -p %{SOURCE4} $RPM_BUILD_ROOT%{_sbindir}/mdadm-checkarray
install -p %{SOURCE5} $RPM_BUILD_ROOT%{systemdunitdir}/cronjob-mdadm.timer
install -p %{SOURCE6} $RPM_BUILD_ROOT%{systemdunitdir}/cronjob-mdadm.service

ln -s /dev/null $RPM_BUILD_ROOT%{systemdunitdir}/mdadm.service

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/chkconfig --add %{name}
%service mdadm restart "RAID monitoring"
%systemd_post mdmonitor.service cronjob-mdadm.timer

%preun
if [ "$1" = "0" ]; then
	%service mdadm stop
	/sbin/chkconfig --del mdadm
fi
%systemd_preun mdmonitor.service cronjob-mdadm.timer

%postun
/sbin/ldconfig
%systemd_reload

%triggerpostun -- %{name} < 4.0-3
%systemd_service_enable cronjob-mdadm.timer

%files
%defattr(644,root,root,755)
%doc ANNOUNCE* ChangeLog TODO
%attr(755,root,root) %{_sbindir}/mdadm
%attr(755,root,root) %{_sbindir}/mdadm-checkarray
%attr(755,root,root) %{_sbindir}/mdctl
%attr(755,root,root) %{_sbindir}/mdmon
%{systemdunitdir}-shutdown/mdadm.shutdown
%{systemdunitdir}/mdadm-grow-continue@.service
%{systemdunitdir}/mdadm-last-resort@.service
%{systemdunitdir}/mdadm-last-resort@.timer
%{systemdunitdir}/mdadm.service
%{systemdunitdir}/mdmon@.service
%{systemdunitdir}/mdmonitor.service
%{systemdunitdir}/cronjob-mdadm.service
%{systemdunitdir}/cronjob-mdadm.timer
/lib/udev/rules.d/01-md-raid-creating.rules
/lib/udev/rules.d/63-md-raid-arrays.rules
/lib/udev/rules.d/64-md-raid-assembly.rules
/lib/udev/rules.d/69-md-clustered-confirm-device.rules
%attr(640,root,root) %config(noreplace,missingok) %verify(not md5 mtime size) %{_sysconfdir}/mdadm.conf
%{_mandir}/man4/md.4*
%{_mandir}/man5/mdadm.conf.5*
%{_mandir}/man8/mdadm.8*
%{_mandir}/man8/mdmon.8*
%attr(754,root,root) /etc/rc.d/init.d/%{name}
%attr(640,root,root) %config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/%{name}
%config(noreplace) %attr(640,root,root) /etc/cron.d/mdadm-checkarray

%if %{with initrd}
%files initrd
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/initrd/mdadm
%attr(755,root,root) %{_libdir}/initrd/mdctl
%endif
%changelog
* Tue Dec 18 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/mdadm.git;a=log;h=master

* Tue Dec 18 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 6248b88
- rel 1

* Mon Nov 26 2018 Jakub Bogusz <qboosh@pld-linux.org> cb64f53
- deduped macros BR

* Mon Nov 26 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> b0b728a
- up to 4.1; there is no mdassemble anymore. Note rel 0.1 is there only because our geninitrd require mdassemble for initrd. TODO: fix geninitrd and add proper deps

* Mon Nov 26 2018 Jakub Bogusz <qboosh@pld-linux.org> 915e915
- use __mv macro

* Fri Oct 06 2017 Jacek Konieczny <j.konieczny@eggsoft.pl> 555514b
- mask mdadm.service, activate mdmonitor.service instead

* Sun Oct 01 2017 Arkadiusz Miśkiewicz <arekm@maven.pl> aa02881
- rel 4; use mdadm provided udev/systemd rules

* Fri Mar 10 2017 Jacek Konieczny <j.konieczny@eggsoft.pl> 668ee27
- systemd-cronjobs support added

* Fri Mar 10 2017 Jacek Konieczny <j.konieczny@eggsoft.pl> 7a20491
- BR: dlm-devel

* Sat Feb 25 2017 Jan Rękorajski <baggins@pld-linux.org> 79d5f6a
- add systemd service
- rel 2

* Tue Jan 10 2017 Arkadiusz Miśkiewicz <arekm@maven.pl> 4b3081c
- up to 4.0 (new maintainer)

* Tue Mar 29 2016 Jakub Bogusz <qboosh@pld-linux.org> 6737f60
- updated to 3.4 (now supports journalled RAID5/6 and clustered RAID1)

* Tue Aug 11 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> bae2bf9
- up to 3.3.4

* Sun Mar 01 2015 Elan Ruusamäe <glen@delfi.ee> 028b344
- x32 rebuild
- release 2 (by relup.sh)

* Fri Aug 22 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> a7087c9
- up to 3.3.2

* Tue Aug 05 2014 Marcin Krol <hawk@tld-linux.org> 3441ea1
- upstream fix for array assembling

* Thu Jun 05 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> df9a0ef
- up to 3.3.1

* Wed May 14 2014 Elan Ruusamäe <glen@delfi.ee> ec5e523
- suggest/require crondaemon
- release 5 (by relup.sh)

* Sat Feb 01 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> d8df675
- rel 4; build mdassemble separately and turn on MDASSEMBLE_AUTO, so we get working mdassemble

* Sat Feb 01 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> d8d18d9
- rel 3; install non-initrd mdassemble, too (for geninitrd use)

* Fri Jan 31 2014 Jan Rękorajski <baggins@pld-linux.org> 26a8f59
- disable/remove initrd subpackage
- rel 2

